import com.atlassian.jira.component.ComponentAccessor
import org.apache.log4j.Logger

serviceDesk = new ServiceDeskTool()

/**
 * Velocity tool to get JIRA Service Desk ticket data.
 */
class ServiceDeskTool {
	def log = Logger.getLogger(this.getClass())

	/* JIRA Service Desk API. */
	def approvalServiceInitialized = false
	def approvalService

	/**
	 * Returns the decisions for an approval (as a map from the approver's display name to the decision).
	 */
	def getApprovalDecisions(def user, def approval) {
		// lazily load dependency (attempt only once)
		if(!approvalServiceInitialized) {
			try {
				def approvalServiceClass = Class.forName("com.atlassian.servicedesk.api.approval.ApprovalService")
				approvalService = ComponentAccessor.getOSGiComponentInstanceOfType(approvalServiceClass)
			} catch (Exception ex) {
				log.warn("Failed to find the ApprovalService", ex)
			}
			approvalServiceInitialized = true
		}

		def decisions = [:]
		if(approvalService && approvalService.getApprovers(user, approval).isRight()) {
			def approvers = approvalService.getApprovers(user, approval).right().get()
			approvers.each {
				decisions.put(it.approverUser.displayName, it.approverDecision)
			}
		} else {
			log.warn("Failed to get approvers")
		}

		return decisions
	}
}
