import org.apache.commons.io.IOUtils
import org.apache.log4j.Logger

tempo = new TempoTool(apiToken: tempoApiToken, baseUrl: baseurl, dateFrom: tempoDateFrom, dateTo: tempoDateTo)

/**
 * Velocity tool to get Tempo worklogs from the Tempo Servlet API.
 *
 * @see https://tempoplugin.jira.com/wiki/display/TEMPO/Tempo+Servlet+Manual
 */
class TempoTool {
	def log = Logger.getLogger(this.getClass())

	/* Tempo servlet request parameters. */
	String apiToken
	String baseUrl
	String dateFrom
	String dateTo

	def slurper = new XmlSlurper()

	/**
	 * Returns the Tempo managed worklogs for the passed issue (as <code>groovy.util.slurpersupport.GPathResult</code> in the standard Tempo Servlet XML format),
	 * or the exception object if something went wrong.
	 * You can access the returned XML node values using their original names in Tempo, like "issue_key", "hours" or "activity_name".
	 */
	def getWorklogs(def issueKey) {
		log.debug("Downloading Tempo worklogs for ${issueKey}")
		InputStream inputStream

		try {
			// note: you can't filter by username (the Tempo API can filter either by issue key or by username, but not both)
			def url = "${baseUrl}/plugins/servlet/tempo-getWorklog/?issueKey=${issueKey}&dateFrom=${dateFrom}&dateTo=${dateTo}&format=xml&addBillingInfo=true&addUserDetails=true&tempoApiToken=${apiToken}"
			log.debug("Tempo URL for ${issueKey}: ${url}")

			inputStream = new URL(url).openStream()
			def xml = IOUtils.toString(inputStream, "UTF-8")
			log.trace("Tempo XML for ${issueKey}:\n${xml}")

			def result = slurper.parseText(xml)
			def worklogs = result.worklog
			log.debug("${worklogs.size()} Tempo worklogs found for ${issueKey}")

			return worklogs
		} catch(Throwable e) {
			log.error("Failed to download Tempo worklogs", e)
			return e
		} finally {
			IOUtils.closeQuietly(inputStream)
		}
	}
}
